*******************
Spanish Acquisition
*******************

Spanish Acquisition is a Python package for interfacing with test & measurement devices (primarily SCPI over Ethernet and GPIB) and building user interfaces for running experiments.

The compiled documentation is `available online <http://0.github.com/SpanishAcquisition/docs/>`_.

It is released under the FreeBSD (2-clause BSD) license. See the ``LICENSE`` file for details.
